<?php
/**
 * ANATEL
 *
 * 20/02/2017 - criado por marcelo.bezerra - CAST
 *
 */

require_once dirname(__FILE__).'/../../../SEI.php';

class MdPetIntercorrenteReaberturaRN extends InfraRN {
	
	public function __construct(){
		parent::__construct();
	}
	
	protected function inicializarObjInfraIBanco(){
		return BancoSEI::getInstance();
	}
	
	/*
	 * Funo responsvel por verificar se o processo no est aberto em nenhuma unidade e se  necessrio reabri-lo para poder inserir documentos nele
	 * */
	public function isNecessarioReabrirProcedimentoConectado ( ProcedimentoDTO $objProcedimentoDTO ){
		
		$objSEIRN = new SeiRN();
		//Reabre o Processo quando necessrio de Critrio Intercorrente
		$objEntradaConsultaProcApi = new EntradaConsultarProcedimentoAPI();
		$objEntradaConsultaProcApi->setIdProcedimento($objProcedimentoDTO->getDblIdProcedimento());
		$objEntradaConsultaProcApi->setSinRetornarUnidadesProcedimentoAberto('S');
		
		$ret = $objSEIRN->consultarProcedimento($objEntradaConsultaProcApi);
		$arrUnidadesAberto = $ret->getUnidadesProcedimentoAberto();
				
		if( count( $arrUnidadesAberto ) == 0 ){
			
			return true;
		}
		
		return false;
		
	}
	
	/*
	 * Funo responsvel pela reabertura de processo
	 * */
	protected function reabrirProcessoApiConectado(ProcedimentoDTO $objProcedimentoDTO) {
		
		$objSEIRN = new SeiRN();
		//Reabre o Processo quando necessrio de Critrio Intercorrente
		$objEntradaConsultaProcApi = new EntradaConsultarProcedimentoAPI();
		$objEntradaConsultaProcApi->setIdProcedimento($objProcedimentoDTO->getDblIdProcedimento());
		$objEntradaConsultaProcApi->setSinRetornarUnidadesProcedimentoAberto('S');
	
		$ret = $objSEIRN->consultarProcedimento($objEntradaConsultaProcApi);
		$arrUnidadesAberto = $ret->getUnidadesProcedimentoAberto();
		$unidadesAberto = count($arrUnidadesAberto);
	
		if ($unidadesAberto < 0) {
			return false;
		}
		
		$objAtividadeDTO = new AtividadeDTO();
		$objAtividadeDTO->setDblIdProcedimentoProtocolo($objProcedimentoDTO->getDblIdProcedimento());
		$idUnidadeReabrirProcesso = $this->retornaUltimaUnidadeProcessoConcluido($objAtividadeDTO);
	
		$unidadeDTO = new UnidadeDTO();
		$unidadeDTO->retTodos();
		$unidadeDTO->setBolExclusaoLogica(false);
		$unidadeDTO->setNumIdUnidade($idUnidadeReabrirProcesso);
		$unidadeRN = new UnidadeRN();
		$objUnidadeDTO = $unidadeRN->consultarRN0125($unidadeDTO);
		
		if($objUnidadeDTO->getStrSinAtivo() == 'N'){
			$idUnidadeReabrirProcesso = null;
			$objAtividadeRN  = new AtividadeRN();
			$arrObjUnidadeDTO = $objAtividadeRN->listarUnidadesTramitacao($objProcedimentoDTO);
			foreach ($arrObjUnidadeDTO as $itemObjUnidadeDTO) {
				if ($itemObjUnidadeDTO->getStrSinAtivo() == 'S') {
					$idUnidadeReabrirProcesso = $itemObjUnidadeDTO->getNumIdUnidade();
					break;
				}
			}
		}
	
		if (!$idUnidadeReabrirProcesso) {
			return false;
		}
	
		$this->simularLogin($idUnidadeReabrirProcesso);
	
		$objEntradaReabrirProcessoAPI = new EntradaReabrirProcessoAPI();
		$objEntradaReabrirProcessoAPI->setIdProcedimento($objProcedimentoDTO->getDblIdProcedimento());
		$objEntradaReabrirProcessoAPI->setProtocoloProcedimento($objProcedimentoDTO->getStrProtocoloProcedimentoFormatado());
	
		$objSEIRN->reabrirProcesso($objEntradaReabrirProcessoAPI);
		return true;
	}

    private function simularLogin($idUnidade)
    {
        SessaoSEI::getInstance()->simularLogin(null, null, SessaoSEIExterna::getInstance()->getNumIdUsuarioExterno(), $idUnidade);
        //$this->setUnidadeDTO($idUnidade);
    }
    
    /**
     * Retorna a ultima unidade que o processo foi
     * Pesquisa o processo exatamente como foi digitado SEM considerar a formatao
     * @access protected
     * @author Jaqueline Mendes <jaqueline.mendes@cast.com.br>
     * @param  ProtocoloDTO $parObjProtocoloDTO
     * @return mixed
     */
    protected function retornaUltimaUnidadeProcessoConcluidoConectado(AtividadeDTO $objAtividadeDTO){
    
    	$idUnidadeReabrirProcesso = null;
    	$objAtividadeRN  = new AtividadeRN();
    	$objAtividadeDTO->retDthConclusao();
    	$objAtividadeDTO->retNumIdUnidade();
    	$objAtividadeDTO->setOrdDthConclusao(InfraDTO::$TIPO_ORDENACAO_DESC);
    	
    	// apenas considerar para reaburtura SE a tarefa do andamento for 28, 41 ou 63 a saber:
    	//- 28: Conclusao do processo na unidade
    	//- 41: Conclusao automtica de processo na unidade
    	//- 63: Processo concluido
    	
    	$objAtividadeDTO->setNumIdTarefa( array( TarefaRN::$TI_CONCLUSAO_PROCESSO_UNIDADE , TarefaRN::$TI_CONCLUSAO_AUTOMATICA_UNIDADE, TarefaRN::$TI_CONCLUSAO_PROCESSO_USUARIO), InfraDTO::$OPER_IN );
    	    	
    	$arrObjAtividadeDTO = $objAtividadeRN->listarRN0036($objAtividadeDTO);
    	$objUltimaAtvProcesso = count($arrObjAtividadeDTO) > 0 ? current($arrObjAtividadeDTO) : null;
    	
    	if(!is_null($objUltimaAtvProcesso)) {
    		$idUnidadeReabrirProcesso = $objUltimaAtvProcesso->getNumIdUnidade();
    	}
    
    	return $idUnidadeReabrirProcesso;
    }
}